import React, { useState, useEffect } from "react";
import styled from "styled-components";
import cx from "classnames";
import keys from "lodash/keys";

// components
import * as instructions from "Instructions/Index";

// constants
import packageJson from " ../../../package.json";

// style
const StyledLayout = styled.div`
  > header {
    border: #e8e8e8 solid;
    border-width: 0 0 1px 0;
    padding-left: 16px;
    padding-right: 16px;
  }

  > main {
    display: flex;

    > nav {
      min-height: 100vh;
      min-width: 280px;
      background-color: #f5f5f5;
      border: #e8e8e8 solid;
      border-width: 0 1px 0 0;

      .components-wrap {
        margin: 0;
        padding-left: 16px;
        padding-right: 16px;
      }

      .component-name {
        margin: 20px 0;
        color: #1673b1;
        cursor: pointer;

        &.active {
          font-weight: bold;
        }
      }
    }

    .content {
      width: 90%;
      padding: 16px 32px;
      margin: 0 auto;
      box-sizing: border-box;

      .md-preview-section {
        margin-bottom: 48px;

        h2 {
          margin: 0;
          color: #333;
          font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto",
            "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans",
            "Helvetica Neue", sans-serif;
          font-weight: normal;
          font-size: 36px;
        }

        h3 {
          padding: 8px 0;
          font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto",
            "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans",
            "Helvetica Neue", sans-serif;
          font-size: 15px;
          color: #e90;
          background: transparent;
          text-transform: uppercase;
          border: none;
          outline: 0;
        }

        table {
          width: 100%;
          border-collapse: collapse;

          thead {
            border-bottom: 1px solid #e8e8e8;

            tr {
              th {
                color: #333;
                padding-right: 16px;
                padding-bottom: 8px;
                text-align: left;
                font-family: -apple-system, BlinkMacSystemFont, "Segoe UI",
                  "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans",
                  "Droid Sans", "Helvetica Neue", sans-serif;
                font-weight: bold;
                font-size: 13px;
                white-space: nowrap;
              }
            }
          }

          tbody {
            tr {
              border-bottom: 1px solid #e8e8e8;

              &:nth-child(2n) {
                background-color: #f6f8fa;
              }

              td {
                padding: 8px 16px 8px 4px;
                font-family: Consolas, "Liberation Mono", Menlo, monospace;
                font-size: 14px;
                color: #333333;
                background: transparent;
                white-space: inherit;
                line-height: 24px;
                box-sizing: border-box;

                code {
                  font-family: Consolas, "Liberation Mono", Menlo, monospace;
                  font-size: 13px;
                  color: #690;
                }

                em {
                  font-family: Consolas, "Liberation Mono", Menlo, monospace;
                  font-size: 13px;
                  color: #905;
                }

                strong {
                  display: block;
                  font-weight: 400;
                }
              }
            }
          }
        }
      }

      .component-preview-section {
        .title {
          margin-top: 0;
          margin-bottom: 8px;
          font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto",
            "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans",
            "Helvetica Neue", sans-serif;
          line-height: 1.5;
          font-size: 24px;
        }

        .component-preivew-wrap,
        .source-code-preivew-wrap {
          margin-bottom: 24px;
        }

        .component-preivew-wrap {
          width: 100%;

          .title {
            color: #333;
          }

          .component {
            border: 1px #e8e8e8 solid;
            border-radius: 3px;
            padding: 16px;
          }
        }

        .source-code-preivew-wrap {
          .title {
            color: #e90;
            font-size: 15px;
            font-weight: bold;
          }
        }
      }
    }
  }

  > footer {
    text-align: right;
    padding: 0 20px;
    color: #aaaaaa;
    font-size: 14px;
  }
`;

export default () => {
  const [selectedItem, setSelectedItem] = useState();

  useEffect(() => {
    setSelectedItem(keys(instructions)[0] || "");
  }, []);

  return (
    <StyledLayout data-version={packageJson.version} className="root-layout">
      <header>
        <h1>Component(s) Instruction</h1>
      </header>

      <main>
        <nav>
          <div className="components-wrap">
            {keys(instructions).map(key => (
              <div
                key={key}
                className={cx("component-name", {
                  active: key === selectedItem
                })}
                onClick={() => setSelectedItem(key)}
              >
                {key}
              </div>
            ))}
          </div>
        </nav>

        <div className="content">
          {selectedItem &&
            instructions[selectedItem] &&
            React.createElement(instructions[selectedItem])}
        </div>
      </main>

      <footer>v{packageJson.version}</footer>
    </StyledLayout>
  );
};
